@@ -41,6 +41,7 @@
 #ifdef USE_SQL
 # include <radsql.h>
 #endif
+#include <timestr.h>
 
 const char *argp_program_version = "radiusd (" PACKAGE ") " VERSION;
 static char doc[] = N_("GNU radius daemon");
@@ -151,7 +152,6 @@ static RETSIGTYPE sig_handler(int sig);
 void radiusd_main_loop();
 static size_t radius_count_channels();
 void radiusd_run_preconfig_hooks(void *data);
-static int test_shell();	
 struct cfg_stmt config_syntax[];
 
 
@@ -379,6 +379,9 @@ radiusd_setup()
 		auth_port = get_port_number("radius", "udp", DEF_AUTH_PORT);
 	if (acct_port == 0)
 		acct_port = get_port_number("radacct", "udp", auth_port+1);
+#ifdef USE_SNMP
+	snmp_port = get_port_number("snmp", "udp", 161);
+#endif
         srand(time(NULL));
 
 	/* Register radiusd hooks first. This ensures they will be
@@ -491,7 +494,7 @@ radiusd_main()
 
         case MODE_TEST:
                 common_init();
-                exit(test_shell());
+                tsh();
                 
 #ifdef USE_DBM          
         case MODE_BUILDDBM:
@@ -789,6 +792,7 @@ radiusd_main_loop()
         radlog(L_INFO, _("Ready to process requests."));
 
         for (;;) {
+		log_open(L_MAIN);
 		check_reload();
 		input_select(radius_input, NULL);
 	}
@@ -944,133 +948,6 @@ radiusd_signal_init(RETSIGTYPE (*hp)(int sig))
 		signal(signum[i], hp);
 }
 
-
-/* ****************************** Test Shell ******************************* */
-   
-static char buf[128];
-int doprompt;
-
-static char *
-moreinput(char *buf, size_t bufsize)
-{
-        if (doprompt)
-                printf("%% ");
-        return fgets(buf, bufsize, stdin);
-}
-
-static int
-test_shell()
-{
-        char *tok;
-        int c;
-        NAS *nas;
-        struct radutmp ut;
-        Datatype type;
-        Datum datum;
-
-        printf("** TEST MODE **\n");
-        doprompt = isatty(fileno(stdin));
-        while (tok = moreinput(buf, sizeof(buf))) {
-                int argc;
-                char **argv;
-
-                while (*tok && isspace(*tok))
-                        tok++;
-                c = strlen(tok);
-                if (c > 1 && tok[c-1] == '\n')
-                        tok[c-1] = 0;
-                c = *tok++;
-                                                                
-                switch (c) {
-                case 0:
-                case '#':
-                        continue;
-                case 'h':
-                case '?':
-                        printf("h,?                       help\n");
-                        printf("q,<EOF>                   quit\n");
-                        printf("c NAS LOGIN SID PORT [IP] checkrad\n");
-                        printf("r FUNCALL                 function call\n");
-                        printf("d LEVEL[,LEVEL]           set debug level\n");
-#ifdef USE_SERVER_GUILE
-                        printf("g                         enter guile shell\n");
-#endif
-                        printf("m                         display memory usage\n"); 
-                        break;
-                case 'd':
-                        set_debug_levels(tok);
-                        break;
-#ifdef USE_SERVER_GUILE
-                case 'g':
-                        scheme_read_eval_loop();
-                        break;
-#endif
-                case 'q':
-                        return 0;
-                case 'c': /* checkrad */
-                        if (argcv_get(tok, "", &argc, &argv)) {
-                                fprintf(stderr, "can't parse input\n");
-                                argcv_free(argc, argv);
-                                continue;
-                        }
-
-                        if (argc < 4 || argc > 5) {
-                                fprintf(stderr, "arg count\n");
-                                continue;
-                        }
-                        nas = nas_lookup_name(argv[0]);
-                        if (!nas) {
-                                printf("bad nas\n");
-                                argcv_free(argc, argv);
-                                continue;
-                        }
-                        ut.nas_address = nas->ipaddr;
-
-                        strncpy(ut.orig_login, argv[1], sizeof(ut.orig_login));
-                        strncpy(ut.session_id, argv[2], sizeof(ut.session_id));
-                        ut.nas_port = atoi(argv[3]);
-                        if (argc == 5) 
-                                ut.framed_address = ip_strtoip(argv[5]);
-                        argcv_free(argc, argv);
-                        printf("%d\n", checkrad(nas, &ut));
-                        break;
-                case 'r':
-                        /* r funcall */
-                        if (interpret(tok, NULL, &type, &datum))
-                                printf("?\n");
-                        else {
-                                switch (type) {
-                                case Integer:
-                                        printf("%d (%u)", datum.ival,
-                                                     (unsigned) datum.ival);
-                                        break;
-					
-                                case String:
-                                        printf("%s", datum.sval);
-                                        break;
-					
-				case Undefined:
-					printf("Undefined");
-					break;
-
-				default:
-					abort();
-                                }
-                                printf("\n");
-                        }
-                        break;
-                case 's':
-                        printf("%d\n", parse_rewrite(tok));
-                        break;
-                case 'm': /*memory statistics */
-                        break;
-                default:
-                        printf("no command\n");
-                }
-        }
-        return 0;
-}
-
 
 /* ************************************************************************* */
 
